/* Nos conectamos al usuario Barna para crear su modelo */

CONNECT userBarna/userBarna@BARNA;

CREATE TABLE OFICINAS_BARCELONA (
	Codigo		VARCHAR2(4) NOT NULL,
	Nombre		VARCHAR2(20) NOT NULL,
	Localidad	VARCHAR2(20) NOT NULL,
	Sede		VARCHAR2(10) NOT NULL,
	Director	VARCHAR2(4) NULL,
CONSTRAINT pk_oficinas PRIMARY KEY (Codigo),
CHECK (Sede ='Barcelona')
);

CREATE TABLE CLIENTES_BARCELONA (
	Codigo	VARCHAR2(7) NOT NULL,
	DNI		VARCHAR2(10) NOT NULL,
	Nombre	VARCHAR2(20)NOT NULL,
	Oficina	VARCHAR2(4) NOT NULL,
CONSTRAINT pk_clientes PRIMARY KEY (Codigo), 
CONSTRAINT fk_clientes_oficinas FOREIGN KEY (Oficina)
		REFERENCES OFICINAS_BARCELONA
);
CREATE TABLE POLIZAS_BARCELONA (
	Numero			VARCHAR2(7) NOT NULL,
	Tipo			VARCHAR2(10) NOT NULL,
	Fecha 			DATE NOT NULL,
	Coberturas 		VARCHAR2(2000) NOT NULL,
	Prima 			NUMBER(10,2) NOT NULL,
	Beneficiarios 	VARCHAR2(2000) NOT NULL,
	Oficina 		VARCHAR2(4) NOT NULL,
CONSTRAINT pk_polizas PRIMARY KEY (Numero), 
CONSTRAINT fk_polizas_oficinas FOREIGN KEY (Oficina)
		REFERENCES OFICINAS_BARCELONA,
CHECK (Tipo IN ('Vida','Hogar','Salud','Automovil','Viaje'))
);
CREATE TABLE CUOTAS_BARCELONA (
	Numero			VARCHAR2(7) NOT NULL,
	Fecha 			DATE NOT NULL,
	Importe			NUMBER(10,2) NOT NULL,
	FechaProximoPago	DATE NOT NULL,
CONSTRAINT pk_cuotas PRIMARY KEY (Numero,Fecha), 
CONSTRAINT fk_cuotas_polizas FOREIGN KEY (Numero)
		REFERENCES POLIZAS_BARCELONA ON DELETE CASCADE,
CHECK (FechaProximoPago>=Fecha)
);
CREATE TABLE DATOS_EMP_BARCELONA (
	Codigo			VARCHAR2(7) NOT NULL,
	DNI 			VARCHAR2(10) NOT NULL,
	Telefono		VARCHAR2(12) NOT NULL,
	FecIniEmp		DATE NOT NULL,
	FecIniOficina	DATE NOT NULL,
	Oficina 		VARCHAR2(4) NOT NULL,
CONSTRAINT pk_datos_emp PRIMARY KEY (Codigo), 
CONSTRAINT fk_datos_emp_oficinas FOREIGN KEY (Oficina)
		REFERENCES OFICINAS_BARCELONA,
CHECK (FecIniOficina >= FecIniEmp)
);
ALTER TABLE OFICINAS_BARCELONA ADD (
CONSTRAINT fk_oficinas_empleados FOREIGN KEY (Director)
		REFERENCES DATOS_EMP_BARCELONA
);

CREATE TABLE TITULARES_BARCELONA (
	Cliente			VARCHAR2(7) NOT NULL,
	Poliza 			VARCHAR2(7) NOT NULL,
CONSTRAINT pk_titulares PRIMARY KEY (Cliente,Poliza), 
CONSTRAINT fk_titulares_clientes FOREIGN KEY (Cliente)
		REFERENCES CLIENTES_BARCELONA,
CONSTRAINT fk_titulares_Polizas FOREIGN KEY (Poliza)
		REFERENCES POLIZAS_BARCELONA ON DELETE CASCADE
);

CREATE TABLE SALARIOS_EMP (
	Codigo			VARCHAR2(7) NOT NULL,
	BandaMin		NUMBER (10,2) NOT NULL,
	BandaMax		NUMBER (10,2) NOT NULL,
	AcumuladoVariable	NUMBER (10,2) NOT NULL,
CONSTRAINT pk_salarios_emp PRIMARY KEY (Codigo), 
CHECK (BandaMax >= BandaMin)
);

ALTER TABLE OFICINAS_BARCELONA DROP
 CONSTRAINT fk_oficinas_empleados;

DROP TABLE DATOS_EMP_BARCELONA;

CREATE TABLE DATOS_EMP (
	Codigo			VARCHAR2(7) NOT NULL,
	DNI 			VARCHAR2(10) NOT NULL,
	Telefono		VARCHAR2(12) NOT NULL,
	FecIniEmp		DATE NOT NULL,
	FecIniOficina	DATE NOT NULL,
	Oficina 		VARCHAR2(4) NOT NULL,
CONSTRAINT pk_datos_emp PRIMARY KEY (Codigo), 
CHECK (FecIniOficina >= FecIniEmp)
);

ALTER TABLE OFICINAS_BARCELONA ADD (
CONSTRAINT fk_oficinas_empleados FOREIGN KEY (Director)
  REFERENCES DATOS_EMP
);

ALTER TABLE SALARIOS_EMP ADD (
CONSTRAINT fk_salarios_datos FOREIGN KEY (Codigo)
		REFERENCES DATOS_EMP ON DELETE CASCADE
);

ALTER TABLE POLIZAS_BARCELONA DROP 
CONSTRAINT fk_polizas_oficinas;

ALTER TABLE CLIENTES_BARCELONA DROP 
CONSTRAINT fk_clientes_oficinas;

DROP TABLE OFICINAS_BARCELONA;

CREATE TABLE OFICINAS (
	Codigo		VARCHAR2(4) NOT NULL,
	Nombre		VARCHAR2(20) NOT NULL,
	Localidad	VARCHAR2(20) NOT NULL,
	Sede		VARCHAR2(10) NOT NULL,
	Director	VARCHAR2(4) NULL,
CONSTRAINT pk_oficinas PRIMARY KEY (Codigo),
CHECK (Sede IN ('Tarragona','Barcelona','Lleida','Girona')),
CONSTRAINT fk_oficinas_empleados FOREIGN KEY (Director)
		REFERENCES DATOS_EMP
);

ALTER TABLE POLIZAS_BARCELONA ADD 
CONSTRAINT fk_polizas_oficinas FOREIGN KEY (Oficina)
		REFERENCES OFICINAS;

ALTER TABLE CLIENTES_BARCELONA ADD 
CONSTRAINT fk_clientes_oficinas FOREIGN KEY (Oficina)
		REFERENCES OFICINAS;
